@@ -28,7 +28,7 @@ Streamlit.setComponentReady();
       const {textAlign}=event.detail.args;
       
       Streamlit.setFrameHeight(height);
-      var card=await waitForElm('.card')
+      var card=await waitForBody('.card')
       document.querySelector("body").style.display='';
       card.style.height=height+"px";
       const titled = document.querySelector(".title span");
@@ -85,27 +85,19 @@ Streamlit.setComponentReady();
       }
     }
 
-    function waitForElm(selector) {
-      return new Promise(resolve => {
-          if (document.querySelector(selector)) {
-              return resolve(document.querySelector(selector));
-          }
-
-          const observer = new MutationObserver(mutations => {
-              if (document.querySelector(selector)) {
-                  resolve(document.querySelector(selector));
-                  observer.disconnect();
-              }
-          });
-          try {
-              observer.observe(document.body, {
-              childList: true,
-              subtree: true
-          });
-          } catch (error) {
-            console.log('not ready, no body :-)')
-          }
-      });
+    async function waitForBody(selector, timeout = 10000) {
+      const start = Date.now();
+    
+      while (Date.now() - start < timeout) {
+        const el = document.querySelector(selector);
+        if (el) {
+          return el;
+        }
+        console.log('Not found yet...')
+        await new Promise(resolve => setTimeout(resolve, 300));
+      }
+    
+      return null;
     }
 
     function animateText(elem,duration){
